define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-minute-short@localeAlias1314": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"field-weekOfMonth-short@localeAlias1272": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"AH"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-second-narrow@localeAlias1318": {
		"bundle": "",
		"target": "field-second-short"
	},
	"dateFormatItem-Ehm": "E h:mm a",
	"field-second-narrow@localeAlias1319": {
		"bundle": "",
		"target": "field-second"
	},
	"days-standAlone-short@localeAlias1228": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"days-standAlone-short@localeAlias1229": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"days-standAlone-short@localeAlias1230": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"days-format-narrow@localeAlias1223": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"dateTime@localeAlias1255": {
		"bundle": "islamic",
		"target": "dateTime"
	},
	"field-second-short@localeAlias1317": {
		"bundle": "",
		"target": "field-second"
	},
	"dateTime@localeAlias1256": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"field-weekdayOfMonth-narrow@localeAlias1285": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias1286": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-zone-short@localeAlias1320": {
		"bundle": "",
		"target": "field-zone"
	},
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-week-narrow@localeAlias1270": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-mon-relative+1": "next Monday",
	"field-week-narrow@localeAlias1271": {
		"bundle": "",
		"target": "field-week"
	},
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-minute-narrow@localeAlias1315": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-sat-narrow-relative+0": "this Saturday",
	"field-minute-narrow@localeAlias1316": {
		"bundle": "",
		"target": "field-minute"
	},
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"timeFormat@localeAlias1253": {
		"bundle": "islamic",
		"target": "timeFormat"
	},
	"timeFormat@localeAlias1254": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"dayPeriods-standAlone-wide@localeAlias1246": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias1247": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-sun-narrow@localeAlias1288": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias1289": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-month": "Month",
	"field-dayOfYear-narrow@localeAlias1279": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dayPeriods@localeAlias1239": {
		"bundle": "islamic",
		"target": "dayPeriods"
	},
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"quarters-standAlone-wide@localeAlias1238": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-mon-narrow@localeAlias1291": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-mon-narrow@localeAlias1292": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-dayOfYear-narrow@localeAlias1280": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"dayPeriods@localeAlias1240": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"quarters-format-abbr@localeAlias1234": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-weekOfMonth-narrow@localeAlias1273": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias1274": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-sat-short@localeAlias1305": {
		"bundle": "",
		"target": "field-sat"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-tue-short@localeAlias1293": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dayPeriods-standAlone-narrow@localeAlias1244": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias1245": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-weekdayOfMonth-short@localeAlias1284": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"field-day-short@localeAlias1275": {
		"bundle": "",
		"target": "field-day"
	},
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"field-era-narrow@localeAlias1258": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"days-format-abbr@localeAlias1222": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-era-narrow@localeAlias1259": {
		"bundle": "",
		"target": "field-era"
	},
	"field-sat-relative+-1": "last Saturday",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"quarters-format-narrow@localeAlias1235": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"AH"
	],
	"field-second-short": "Second",
	"field-fri-narrow@localeAlias1303": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias1304": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-tue-narrow@localeAlias1294": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"field-tue-narrow@localeAlias1295": {
		"bundle": "",
		"target": "field-tue"
	},
	"dayPeriods-format-wide@localeAlias1242": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"eraAbbr": [
		"AH"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-hour-narrow@localeAlias1312": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-hour-narrow@localeAlias1313": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-second-relative+0": "now",
	"field-day-narrow@localeAlias1276": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias1277": {
		"bundle": "",
		"target": "field-day"
	},
	"field-quarter-relative+-1": "last quarter",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-standAlone-abbr@localeAlias1243": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"eraNarrow@localeAlias1250": {
		"bundle": "islamic",
		"target": "eraAbbr"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-mon-short@localeAlias1290": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-sun-short@localeAlias1287": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-hour-short@localeAlias1311": {
		"bundle": "",
		"target": "field-hour"
	},
	"quarters-standAlone-abbr@localeAlias1236": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias1237": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-dayperiod-short@localeAlias1308": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dateFormatItem-Bhms": "h:mm:ss B",
	"days-standAlone-wide@localeAlias1231": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-hour": "Hour",
	"field-zone-narrow@localeAlias1321": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-zone-narrow@localeAlias1322": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"dateFormat@localeAlias1251": {
		"bundle": "islamic",
		"target": "dateFormat"
	},
	"dateFormat@localeAlias1252": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"dateFormatItem-yyyy": "G y",
	"field-sat-narrow@localeAlias1306": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias1307": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-thu-narrow@localeAlias1300": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-thu-narrow@localeAlias1301": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"months-standAlone-wide@localeAlias1219": {
		"bundle": "islamic",
		"target": "months-format-wide"
	},
	"field-day": "Day",
	"field-week-short@localeAlias1269": {
		"bundle": "",
		"target": "field-week"
	},
	"dayPeriods-format-narrow@localeAlias1241": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-mon-relative+-1": "last Monday",
	"field-weekday-narrow@localeAlias1282": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow@localeAlias1283": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear": "Day Of Year",
	"field-year-short@localeAlias1260": {
		"bundle": "",
		"target": "field-year"
	},
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"era@localeAlias1248": {
		"bundle": "islamic",
		"target": "era"
	},
	"field-month-short@localeAlias1266": {
		"bundle": "",
		"target": "field-month"
	},
	"field-fri-short@localeAlias1302": {
		"bundle": "",
		"target": "field-fri"
	},
	"dateFormatItem-GyMMMd": "G y MMM d",
	"days@localeAlias1220": {
		"bundle": "islamic",
		"target": "days"
	},
	"dateFormatItem-MEd": "MM-dd, E",
	"days@localeAlias1221": {
		"bundle": "gregorian",
		"target": "days"
	},
	"quarters@localeAlias1232": {
		"bundle": "islamic",
		"target": "quarters"
	},
	"field-tue-short-relative+-1": "last Tuesday",
	"quarters@localeAlias1233": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"field-dayperiod-narrow@localeAlias1309": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-year-short": "Year",
	"field-month-short": "Month",
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-dayperiod-narrow@localeAlias1310": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"eraNames@localeAlias1249": {
		"bundle": "islamic",
		"target": "eraAbbr"
	},
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months@localeAlias1216": {
		"bundle": "islamic",
		"target": "months"
	},
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-narrow@localeAlias1264": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias1265": {
		"bundle": "",
		"target": "field-quarter"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-month-narrow@localeAlias1267": {
		"bundle": "",
		"target": "field-month-short"
	},
	"field-week-narrow-relative+-1": "last week",
	"field-month-narrow@localeAlias1268": {
		"bundle": "",
		"target": "field-month"
	},
	"days-format-short@localeAlias1224": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-format-short@localeAlias1225": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-dayOfYear-short@localeAlias1278": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-year-narrow@localeAlias1261": {
		"bundle": "",
		"target": "field-year-short"
	},
	"field-wed-relative+-1": "last Wednesday",
	"field-year-narrow@localeAlias1262": {
		"bundle": "",
		"target": "field-year"
	},
	"field-weekOfMonth": "Week Of Month",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-fri-relative+-1": "last Friday",
	"field-wed-narrow@localeAlias1297": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-wed-narrow@localeAlias1298": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"months-format-narrow@localeAlias1217": {
		"bundle": "islamic",
		"target": "months-standAlone-narrow"
	},
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"days-standAlone-abbr@localeAlias1226": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"days-standAlone-abbr@localeAlias1227": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"dateFormatItem-Gy": "G y",
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"field-era-short@localeAlias1257": {
		"bundle": "",
		"target": "field-era"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "this week",
	"field-quarter-short@localeAlias1263": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-week-relative+1": "next week",
	"field-weekday-short@localeAlias1281": {
		"bundle": "",
		"target": "field-weekday"
	},
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"months-standAlone-abbr@localeAlias1218": {
		"bundle": "islamic",
		"target": "months-format-abbr"
	},
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-wed-short@localeAlias1296": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-month-short-relative+-1": "last month",
	"field-thu-short@localeAlias1299": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
});